;; Generated package description from bufferlo.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "bufferlo" "1.1.0.20250818.175416" "Frame/Tab Local Buffer Lists with Persistence" '((emacs "29.1")) :commit "62acb6a36e63b65243e719354aa328f006945f95" :authors '(("Florian Rommel" . "mail@florommel.de") ("Stephane Marks" . "shipmints@gmail.com")) :maintainer '(("Florian Rommel" . "mail@florommel.de") ("Stephane Marks" . "shipmints@gmail.com")) :keywords '("buffer" "frame" "tabs" "local") :url "https://github.com/florommel/bufferlo")
